summaryrefslogtreecommitdiff
path: root/logger
diff options
context:
space:
mode:
authorDavid Laban <david.laban@collabora.co.uk>2011-05-24 19:45:08 -0400
committerDavid Laban <david.laban@collabora.co.uk>2011-05-24 19:58:50 -0400
commit3b6ea3563c3e43ebd5f91c19464c6dc7ca018b3a (patch)
treefdfa62b1f91123c7bee87ab8d21ef7d15e7566eb /logger
parent3b28093785033d9820f78a9af77d6c4a1e318bd1 (diff)
Update tests to use original-timestamp
Diffstat (limited to 'logger')
-rw-r--r--logger/tests/dbus/test-tpl-log-store-xml.c14
1 files changed, 9 insertions, 5 deletions
diff --git a/logger/tests/dbus/test-tpl-log-store-xml.c b/logger/tests/dbus/test-tpl-log-store-xml.c
index 0e585367f..f621a35de 100644
--- a/logger/tests/dbus/test-tpl-log-store-xml.c
+++ b/logger/tests/dbus/test-tpl-log-store-xml.c
@@ -522,8 +522,9 @@ test_add_superseding_event (XmlTestCaseFixture *fixture,
"account", account,
"sender", me,
"receiver", contact,
- "timestamp", timestamp,
+ "timestamp", timestamp + 2,
/* TplTextEvent */
+ "original-timestamp", timestamp,
"message-token", "OMGCOMPLETELYRANDOMSTRING2",
"supersedes-token", "OMGCOMPLETELYRANDOMSTRING1",
"message-type", TP_CHANNEL_TEXT_MESSAGE_TYPE_NORMAL,
@@ -552,8 +553,9 @@ test_add_superseding_event (XmlTestCaseFixture *fixture,
"account", account,
"sender", me,
"receiver", contact,
- "timestamp", timestamp,
+ "timestamp", timestamp + 3,
/* TplTextEvent */
+ "original-timestamp", timestamp,
"message-token", "OMGCOMPLETELYRANDOMSTRING3",
"supersedes-token", "OMGCOMPLETELYRANDOMSTRING1",
"message-type", TP_CHANNEL_TEXT_MESSAGE_TYPE_NORMAL,
@@ -587,14 +589,15 @@ test_add_superseding_event (XmlTestCaseFixture *fixture,
g_list_foreach (events, (GFunc) g_object_unref, NULL);
g_list_free (events);
/* 4. Edit comes in with the wrong timestamp. */
late_event = g_object_new (TPL_TYPE_TEXT_EVENT,
/* TplEvent */
"account", account,
"sender", me,
"receiver", contact,
- "timestamp", timestamp + (60 * 60 * 24),
+ "timestamp", timestamp + 4,
/* TplTextEvent */
+ "original-timestamp", timestamp + (60 * 60 * 24),
"message-token", "OMGCOMPLETELYRANDOMSTRING4",
"supersedes-token", "OMGCOMPLETELYRANDOMSTRING1",
"message-type", TP_CHANNEL_TEXT_MESSAGE_TYPE_NORMAL,
@@ -634,8 +637,9 @@ test_add_superseding_event (XmlTestCaseFixture *fixture,
"account", account,
"sender", me,
"receiver", contact,
- "timestamp", timestamp - (60 * 60 * 24),
+ "timestamp", timestamp + 5,
/* TplTextEvent */
+ "original-timestamp", timestamp - (60 * 60 * 24),
"message-token", "OMGCOMPLETELYRANDOMSTRING5",
"supersedes-token", "OMGCOMPLETELYRANDOMSTRING1",
"message-type", TP_CHANNEL_TEXT_MESSAGE_TYPE_NORMAL,
@@ -587,14 +589,15 @@ test_add_superseding_event (XmlTestCaseFixture *fixture,
g_list_foreach (events, (GFunc) g_object_unref, NULL);
g_list_free (events);
- /* 4. Edit comes in with the wrong timestamp. */
+ /* 4. Edit comes in with the wrong original-timestamp. */
late_event = g_object_new (TPL_TYPE_TEXT_EVENT,
/* TplEvent */